#[non_exhaustive]pub enum CatalogProblem {
Kind {
found: &'static str,
builder: &'static str,
},
UndefinedMaterial(String),
NoWall,
Shape,
NoVolume,
}Expand description
Why a catalog part (hpr_io::orc::Part) can’t be made into a builder part.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Kind
A part of a kind the builder’s part isn’t, such as a body tube given to
Nose::from_catalog.
UndefinedMaterial(String)
A material its file names but doesn’t define, so it has no density.
NoWall
A nose cone or transition neither filled nor given a wall thickness.
Shape
A nose cone’s or transition’s shape the builder doesn’t know.
NoVolume
A part that states its mass but whose sizes give it no volume to hold it, so no density gives it that mass.