#[non_exhaustive]pub struct Recovered {
pub devices: Vec<Device>,
pub not_deployed: Vec<(String, NeverDeploys)>,
pub added: usize,
}Expand description
A .ork configuration’s recovery devices as the flight flies them (recovery).
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.devices: Vec<Device>The devices that deploy, in file order, each named by its part’s name (its id where the name is empty).
not_deployed: Vec<(String, NeverDeploys)>The devices that never deploy in this configuration, by name, with why.
added: usizeHow many devices at the end of devices hpr added rather than read from the file: the
tumbles separated_recovery adds (tumbling). Zero from recovery.