pub struct Mass { /* private fields */ }Expand description
A mass inside the last body tube: a parachute and its cord, an altimeter bay, ballast.
It is a solid cylinder along the axis, as long and as wide as its packing, or a point until
Mass::packed gives it a size. Its Position places the packing’s fore end (Top,
After, Absolute), its aft end (Bottom) or its middle (Middle). So packing a mass
moves its center by half the packed length, unless it is placed by its middle.
Implementations